Fix typos in docstrings, comments and ChangeLogs.
authorJuanma Barranquero <lekktu@gmail.com>
Tue, 12 Oct 2010 15:16:57 +0000 (17:16 +0200)
committerJuanma Barranquero <lekktu@gmail.com>
Tue, 12 Oct 2010 15:16:57 +0000 (17:16 +0200)
* lisp/composite.el (compose-region):
* src/ccl.c (Fccl_execute_on_string): Fix typo in docstring.

17 files changed:
lisp/ChangeLog
lisp/ChangeLog.7
lisp/ChangeLog.8
lisp/ChangeLog.9
lisp/composite.el
lisp/gnus/ecomplete.el
lisp/international/ccl.el
lisp/international/fontset.el
src/ChangeLog
src/ChangeLog.7
src/ccl.c
src/dispextern.h
src/font.h
src/print.c
src/regex.c
src/w32font.c
src/w32uniscribe.c

index 58316a61b1bf64d8bef0123209dc4968946e16b2..747f166dcd1e09f1a6e0ce9cc37bbfcac4c1c5e9 100644 (file)
@@ -1,11 +1,15 @@
- 2010-10-10  Jan Djärv  <jan.h.d@swipnet.se>
-       * term/ns-win.el (ns-right-alternate-modifier): New defvar.
-       (ns-right-option-modifier): New alias for ns-right-alternate-modifier.
-       (mac-right-option-modifier): New alias for ns-right-option-modifier.
-       * cus-start.el (all): ns-right-alternate-modifier is new.
+2010-10-12  Juanma Barranquero  <lekktu@gmail.com>
+
+       * composite.el (compose-region): Fix typo in docstring.
+
+2010-10-10  Jan Djärv  <jan.h.d@swipnet.se>
+
+       * term/ns-win.el (ns-right-alternate-modifier): New defvar.
+       (ns-right-option-modifier): New alias for ns-right-alternate-modifier.
+       (mac-right-option-modifier): New alias for ns-right-option-modifier.
+
+       * cus-start.el (all): ns-right-alternate-modifier is new.
+
 2010-10-10  Andreas Schwab  <schwab@linux-m68k.org>
 
        * Makefile.in (ELCFILES): Update.
index 6858c07d8521e2e32d4ebfd84e75feadd47809f5..cc813b263c0bfd961d717cc297178e043801c159 100644 (file)
        (quail-prev-translation-block): Likewise.
        (quail-conversion-backward-char): Call quail-error instead of
        error.  Set quail-translating to nil.
-       (quail-conversion-forward-char): Likewize.
+       (quail-conversion-forward-char): Likewise.
        (quail-conversion-delete-char): Call quail-error instead of error.
        If conversion region gets vacant, set quail-converting to nil.
-       (quail-conversion-backward-delete-char): Likewize.
+       (quail-conversion-backward-delete-char): Likewise.
        (quail-no-conversion): Just set quail-converting to nil.
        (quail-mouse-choose-completion): Call quai-error instead of error.
        (quail-choose-completion-string): Likewise.
index 8ecf3f0e33af9eb60c5792061d3134fb0614092d..fadec1174c86e8cbbbfccf634368746e29079226 100644 (file)
 
        * language/ethio-util.el (setup-ethiopic-environment-internal):
        Use quail-activate-hook instead of obsolete hook quail-mode-hook.
-       (exit-ethiopic-environment): Likewize.
+       (exit-ethiopic-environment): Likewise.
 
 1999-06-12  Richard M. Stallman  <rms@gnu.org>
 
index b5b42b5b912f333ca7c3aaf28373fe46a577dc5f..e338caee2b57619890c01e430bbf9d9e31d2f408 100644 (file)
        0.  Give correct argument to set-auto-coding-function.
        (tar-expunge): For goto-char, use (point-min), not 0.
        (tar-clear-modification-flags): For goto-char, use (point-min), not 1.
-       (tar-subfile-save-buffer): Likewize.
+       (tar-subfile-save-buffer): Likewise.
 
        * international/mule.el
        (after-insert-file-set-buffer-file-coding-system): Call
        (ccl-decode-viscii): Use translate-character.
        (ccl-encode-viscii, ccl-encode-viscii-font)
        (ccl-decode-vscii, ccl-encode-vscii, ccl-encode-vscii-font):
-       Likewize.
+       Likewise.
 
        * language/cyrillic.el: Remove eval-when-compile.
        (cyrillic-koi8-r-nonascii-translation-table): Define it as a
        (cyrillic-koi8-r-encode-table): Define it as a translation table
        made from the reverse map of above.
        (ccl-decode-koi8): Use translate-character.
-       (ccl-encode-koi8, ccl-encode-koi8-font): Likewize
+       (ccl-encode-koi8, ccl-encode-koi8-font): Likewise.
        (cyrillic-alternativnyj-nonascii-translation-table): Define it as
        a translation table made from cyrillic-alternativnyj-decode-table.
        (cyrillic-alternativnyj-encode-table): Define it as a translation
        table made from the reverse map of above.
        (ccl-decode-alternativnyj): Use translate-character.
        (ccl-encode-alternativnyj, ccl-encode-alternativnyj-font):
-       Likewize
+       Likewise.
 
        * international/mule-diag.el (non-iso-charset-alist): Specify
        translation table symbol instead of translation table itself.
 
        * emacs-lisp/cl-macs.el: Doc fixes; mainly avoid duplicating arg
        list in doc string.  Don't quote keyword symbols.
-       * emacs-lisp/cl.el: Likewise
-       * emacs-lisp/cl-seq.el: Likewise
+       * emacs-lisp/cl.el: Likewise.
+       * emacs-lisp/cl-seq.el: Likewise.
 
 2000-05-05  Gerd Moellmann  <gerd@gnu.org>
 
index 5b01718fc715402b8e88c961c0ecce01051016bd..b5ef9b510c6957543d69047594bccdb77ee2648d 100644 (file)
@@ -210,7 +210,7 @@ of the text in the region.
 
 If it is a string, the elements are alternate characters.  In
 this case, TAB element has a special meaning.  If the first
-characer is TAB, the glyphs are displayed with left padding space
+character is TAB, the glyphs are displayed with left padding space
 so that no pixel overlaps with the previous column.  If the last
 character is TAB, the glyphs are displayed with right padding
 space so that no pixel overlaps with the following column.
index 7952c37f3960e78855c0772a5124c42fdad4c822..7aca7492a6df88c43c8ed32338835aad073f5398 100644 (file)
     (save-restriction
       (narrow-to-region (point) (point-at-eol))
       (while (not (eobp))
-       ;; Put the 'region face on any charactes on this line that
+       ;; Put the 'region face on any characters on this line that
        ;; aren't already highlighted.
        (unless (get-text-property (point) 'face)
          (put-text-property (point) (1+ (point)) 'face 'highlight))
index 09510cd8b00120674821aed4381d25b72b0ff4da..4dc54859ec5baca11391639b4387095ad892634c 100644 (file)
@@ -1437,7 +1437,7 @@ OPERATOR :=
        ;; Normal arithmethic operators (same meaning as C code).
        + | - | * | / | %
 
-       ;; Bitwize operators (same meaning as C code)
+       ;; Bitwise operators (same meaning as C code)
        | & | `|' | ^
 
        ;; Shifting operators (same meaning as C code)
index ecb2088de89fc17d4fa19dc3d189d1f0fc1db71b..1a5823826ddb5e5228b4f873e1a0a6936f75d171 100644 (file)
@@ -700,7 +700,7 @@ Internal use only.  Should be called at startup time."
 ;; "HP-Hebrew8"                                    [36]
 ;;         HPHEBREW8 8-bit character set
 ;; "HP-Japanese15"                                 [36]
-;;         HPJAPAN15 15-bit characer set,
+;;         HPJAPAN15 15-bit character set,
 ;;         modified from industry defacto
 ;;         standard Shift-JIS
 ;; "HP-Kana8"                                      [36]
index b0759b00223a600960a58ce7ba66b0c54c02137c..19f6e568bcd9bc8e638a18a478299af21a700bc3 100644 (file)
@@ -1,3 +1,7 @@
+2010-10-12  Juanma Barranquero  <lekktu@gmail.com>
+
+       * ccl.c (Fccl_execute_on_string): Fix typo in docstring.
+
 2010-10-10  Jan Djärv  <jan.h.d@swipnet.se>
 
        * nsterm.m (Qleft): Declare.
index 6cc3d0f9e3ecf828444dc3971239e7fa219dab8e..a334b4806da647e912ada0cb0f0718c9090af780 100644 (file)
 
        * xselect.c (selection_data_to_lisp_data): Set
        Vlast_coding_system_used.
-       (lisp_data_to_selection_data): Likewize.
+       (lisp_data_to_selection_data): Likesize.
 
 1998-07-07  Richard Stallman  <rms@psilocin.ai.mit.edu>
 
        * editfns.c (Fformat): Replace explicit numeric constants with
        proper macros.
 
-       * fns.c (concat): Likewize.
+       * fns.c (concat): Likewise.
 
 1998-07-06  Kenichi Handa  <handa@etl.go.jp>
 
index c33df9e56de0b12ee28ab6bf4d3271a6970c3586..ac1d7be621c1035f03db48648e8fef54bf42e0d0 100644 (file)
--- a/src/ccl.c
+++ b/src/ccl.c
@@ -450,7 +450,7 @@ extern int charset_unicode;
    Therefore, the instruction code range is 0..16384(0x3fff).
  */
 
/* Read a multibyte characeter.
    A code point is stored into reg[rrr].  A charset ID is stored into
    reg[RRR].  */
 
@@ -2058,7 +2058,7 @@ If R0..R7 are nil, they are initialized to 0.
 If IC is nil, it is initialized to head of the CCL program.
 
 If optional 4th arg CONTINUE is non-nil, keep IC on read operation
-when read buffer is exausted, else, IC is always set to the end of
+when read buffer is exhausted, else, IC is always set to the end of
 CCL-PROGRAM on exit.
 
 It returns the contents of write buffer as a string,
index 076d9055859e4f21c98e04721d809c2bce0b7e39..ca91c5b681207d1a225e726dd4022e7db69dc13c 100644 (file)
@@ -1873,7 +1873,7 @@ struct composition_it
      are not iterating over a composition now.  */
   int id;
   /* If non-negative, character that triggers the automatic
-     composition at `stop_pos', and this is an automatic compositoin.
+     composition at `stop_pos', and this is an automatic composition.
      If negative, this is a static composition.  This is set to -2
      temporarily if searching of composition reach a limit or a
      newline.  */
index 952ea2694957dc2e484fc7174113a4ec205f1772..96227ffe40ba1f5bee02b256215d7a32dfa47e8d 100644 (file)
@@ -574,7 +574,7 @@ struct font_driver
      FONT-ENTITY and it must be opened to check it, return -1.  */
   int (*has_char) P_ ((Lisp_Object font, int c));
 
/* Return a glyph code of FONT for characer C (Unicode code point).
      If FONT doesn't have such a glyph, return FONT_INVALID_CODE.  */
   unsigned (*encode_char) P_ ((struct font *font, int c));
 
index ccbf8d8c0c789ae3451d0954960a9acc9d80dbeb..43f17a7c15d16772228af4bd37b91e822a5f40f7 100644 (file)
@@ -1450,7 +1450,7 @@ static void print_check_string_charset_prop ();
 #define PRINT_STRING_NON_CHARSET_FOUND 1
 #define PRINT_STRING_UNSAFE_CHARSET_FOUND 2
 
-/* Bitwize or of the abobe macros. */
+/* Bitwise or of the above macros. */
 static int print_check_string_result;
 
 static void
index 85ff9b99604465bd4a28d8697508db212eae9b2e..7d12089fea2a8281024973f680dcdcc715da87c2 100644 (file)
@@ -4145,7 +4145,7 @@ analyse_first (p, pend, fastmap, multibyte)
                   && match_any_multibyte_characters == false)
            {
              /* Set fastmap[I] to 1 where I is a leading code of each
-                multibyte characer in the range table. */
+                multibyte character in the range table. */
              int c, count;
              unsigned char lc1, lc2;
 
index e93dbca2ddbf4e2dac0c508e8050e70acd95092e..a07762e970f714dc441ca90109990f0bb5e43812 100644 (file)
@@ -346,7 +346,7 @@ w32font_has_char (entity, c)
 }
 
 /* w32 implementation of encode_char for font backend.
-   Return a glyph code of FONT for characer C (Unicode code point).
+   Return a glyph code of FONT for character C (Unicode code point).
    If FONT doesn't have such a glyph, return FONT_INVALID_CODE.
 
    For speed, the gdi backend uses unicode (Emacs calls encode_char
index cfdf629ceee05e6ea6f12a5fd20e5be061e92f08..9cd1ac6426c9ff56a912b07dbc615953c2de552d 100644 (file)
@@ -448,7 +448,7 @@ uniscribe_shape (lgstring)
 }
 
 /* Uniscribe implementation of encode_char for font backend.
-   Return a glyph code of FONT for characer C (Unicode code point).
+   Return a glyph code of FONT for character C (Unicode code point).
    If FONT doesn't have such a glyph, return FONT_INVALID_CODE.  */
 static unsigned
 uniscribe_encode_char (font, c)
@@ -450,7 +450,7 @@ extern int charset_unicode;
  */
 
-/* Read a multibyte characeter.
+/* Read a multibyte character.
    A code point is stored into reg[rrr].  A charset ID is stored into
    reg[RRR].  */
@@ -574,7 +574,7 @@ struct font_driver
   int (*has_char) P_ ((Lisp_Object font, int c));
 
-  /* Return a glyph code of FONT for characer C (Unicode code point).
+  /* Return a glyph code of FONT for character C (Unicode code point).
      If FONT doesn't have such a glyph, return FONT_INVALID_CODE.  */
   unsigned (*encode_char) P_ ((struct font *font, int c));